SystemOrganization addCategory: #'System-Download'!

Object subclass: #BasicCodeLoader
	instanceVariableNames: 'sourceFiles'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Download'!

!BasicCodeLoader commentStamp: '<historical>' prior: 0!
CodeLoader provides a way to load smalltalk source file from local.

Example: 

CodeLoader new 
	loadSourceFiles: (Array with: 
		(#file:, 
		FileDirectory default fullName, 
		'/useless.st')); 
	installSourceFiles !

!BasicCodeLoader class methodsFor: 'CommandLine Handling' stamp: 'EstebanLorenzano 4/4/2012 10:25'!
commandLineHandlerAction: aCommandLine
	"Load the file specified on the command line"
	
	| loader |
	
	loader := self new.
	loader loadSourceFiles: (Array with: ((aCommandLine parameterAt: 1) convertFromSystemString)).
	loader installSourceFiles.! !

!BasicCodeLoader class methodsFor: 'CommandLine Handling' stamp: 'EstebanLorenzano 4/12/2012 14:28'!
commandLineHandlerCondition: aCommandLine
	"Ensure that:
		- there is a parameter
		- it is a valid file name"
		
	aCommandLine hasParameters ifFalse: [ ^ false ].
	^(FileSystem disk resolve: (aCommandLine parameterAt: 1)) asFileReference exists
! !

!BasicCodeLoader class methodsFor: 'CommandLine Handling' stamp: 'EstebanLorenzano 4/4/2012 14:24'!
initialize
	CommandLine 
		register: [ :commandLine | BasicCodeLoader commandLineHandlerAction: commandLine ] 
		if:[ :commandLine | BasicCodeLoader commandLineHandlerCondition: commandLine ] 
		name: #BasicCodeLoader! !

!BasicCodeLoader methodsFor: 'private' stamp: 'EstebanLorenzano 4/4/2012 10:38'!
handleError: error reference: aReference
	"Print a header before failing on an errro / syntax notification from the the script loaded by the given request"
	|stderr|
	
	"spit out a warning if in headless mode, otherwise a debugger will popup"
	Smalltalk isHeadless 
		ifTrue: [ self inform: 'Errors in script loaded from ', aReference fullName ].
																														
	(error isKindOf: SyntaxErrorNotification)
		"for syntax errors we can used the default action"
		ifTrue: [ error defaultAction ]
		"otherwise resignal it"
		ifFalse: [ error pass ]! !

!BasicCodeLoader methodsFor: 'installing' stamp: 'EstebanLorenzano 4/4/2012 10:39'!
installSourceFile: aReference
	"Install the previously loaded source file"

	aReference readStreamDo: [ :stream | 			
		[ ^ (FileSystemFileStream with: stream contents asString) reset fileIn ]
			on: Error, ParserNotification
			do: [ :e| 	self handleError: e reference: aReference ] ].! !

!BasicCodeLoader methodsFor: 'installing' stamp: 'EstebanLorenzano 4/4/2012 10:31'!
installSourceFiles
	"Install the previously loaded source files"

	sourceFiles ifNil: [ ^self ].
	[ sourceFiles do: [ :reference | self installSourceFile: reference ] ]
	ensure: [ sourceFiles := nil ].
	! !

!BasicCodeLoader methodsFor: 'loading' stamp: 'EstebanLorenzano 4/12/2012 14:28'!
loadSourceFiles: anArray
	"Load all the source files in the given array."

	sourceFiles := anArray collect: [ :each | (FileSystem disk resolve: each) asFileReference ].
! !
BasicCodeLoader initialize!
